( cd usr/bin ; rm -rf x86_64-slamd64-linux-gcjh )
( cd usr/bin ; ln -sf gcjh x86_64-slamd64-linux-gcjh )
( cd usr/bin ; rm -rf x86_64-slamd64-linux-gcj )
( cd usr/bin ; ln -sf gcj x86_64-slamd64-linux-gcj )
( cd usr/lib64 ; rm -rf libffi.so )
( cd usr/lib64 ; ln -sf libffi.so.4.0.1 libffi.so )
( cd usr/lib64 ; rm -rf libgcj.so )
( cd usr/lib64 ; ln -sf libgcj.so.8.0.0 libgcj.so )
( cd usr/lib64 ; rm -rf libgij.so )
( cd usr/lib64 ; ln -sf libgij.so.8.0.0 libgij.so )
( cd usr/lib64 ; rm -rf libgcj-tools.so )
( cd usr/lib64 ; ln -sf libgcj-tools.so.8.0.0 libgcj-tools.so )
( cd usr/lib64 ; rm -rf libgcj_bc.so.1 )
( cd usr/lib64 ; ln -sf libgcj_bc.so.1.0.0 libgcj_bc.so.1 )
( cd usr/lib64 ; rm -rf libffi.so.4 )
( cd usr/lib64 ; ln -sf libffi.so.4.0.1 libffi.so.4 )
( cd usr/lib64 ; rm -rf libgij.so.8 )
( cd usr/lib64 ; ln -sf libgij.so.8.0.0 libgij.so.8 )
( cd usr/lib64 ; rm -rf libgcj.so.8 )
( cd usr/lib64 ; ln -sf libgcj.so.8.0.0 libgcj.so.8 )
( cd usr/lib64 ; rm -rf libgcj-tools.so.8 )
( cd usr/lib64 ; ln -sf libgcj-tools.so.8.0.0 libgcj-tools.so.8 )
